==> esp8266-0.3.0.crate: esp8266-0.3.0/src/spi0/spi_wr_status.rs <==
#[doc = "Register `SPI_WR_STATUS` reader"]
pub struct R(crate::R<SPI_WR_STATUS_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_WR_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<SPI_WR_STATUS_SPEC>> for R {
    fn from(reader: crate::R<SPI_WR_STATUS_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_WR_STATUS` writer"]
pub struct W(crate::W<SPI_WR_STATUS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_WR_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<SPI_WR_STATUS_SPEC>> for W {
    fn from(writer: crate::W<SPI_WR_STATUS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `slv_wr_status` reader - In the slave mode, this register are the status register for the master to write into."]
pub struct SLV_WR_STATUS_R(crate::FieldReader<u32, u32>);
impl SLV_WR_STATUS_R {
    pub(crate) fn new(bits: u32) -> Self {
        SLV_WR_STATUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLV_WR_STATUS_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `slv_wr_status` writer - In the slave mode, this register are the status register for the master to write into."]
pub struct SLV_WR_STATUS_W<'a> {
    w: &'a mut W,
}
impl<'a> SLV_WR_STATUS_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | ((value as u32) & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - In the slave mode, this register are the status register for the master to write into."]
    #[inline(always)]
    pub fn slv_wr_status(&self) -> SLV_WR_STATUS_R {
        SLV_WR_STATUS_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - In the slave mode, this register are the status register for the master to write into."]
    #[inline(always)]
    pub fn slv_wr_status(&mut self) -> SLV_WR_STATUS_W {
        SLV_WR_STATUS_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "In the slave mode, this register are the status register for the master to write into.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_wr_status](index.html) module"]
pub struct SPI_WR_STATUS_SPEC;
impl crate::RegisterSpec for SPI_WR_STATUS_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_wr_status::R](R) reader structure"]
impl crate::Readable for SPI_WR_STATUS_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_wr_status::W](W) writer structure"]
impl crate::Writable for SPI_WR_STATUS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_WR_STATUS to value 0"]
impl crate::Resettable for SPI_WR_STATUS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/spi0/spi_wr_status.rs <==
#[doc = "Register `SPI_WR_STATUS` reader"]
pub struct R(crate::R<SPI_WR_STATUS_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_WR_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SPI_WR_STATUS_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SPI_WR_STATUS_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_WR_STATUS` writer"]
pub struct W(crate::W<SPI_WR_STATUS_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_WR_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SPI_WR_STATUS_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SPI_WR_STATUS_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `slv_wr_status` reader - In the slave mode, this register are the status register for the master to write into."]
pub struct SLV_WR_STATUS_R(crate::FieldReader<u32, u32>);
impl SLV_WR_STATUS_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        SLV_WR_STATUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SLV_WR_STATUS_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `slv_wr_status` writer - In the slave mode, this register are the status register for the master to write into."]
pub struct SLV_WR_STATUS_W<'a> {
    w: &'a mut W,
}
impl<'a> SLV_WR_STATUS_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - In the slave mode, this register are the status register for the master to write into."]
    #[inline(always)]
    pub fn slv_wr_status(&self) -> SLV_WR_STATUS_R {
        SLV_WR_STATUS_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - In the slave mode, this register are the status register for the master to write into."]
    #[inline(always)]
    pub fn slv_wr_status(&mut self) -> SLV_WR_STATUS_W {
        SLV_WR_STATUS_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "In the slave mode, this register are the status register for the master to write into.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_wr_status](index.html) module"]
pub struct SPI_WR_STATUS_SPEC;
impl crate::RegisterSpec for SPI_WR_STATUS_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_wr_status::R](R) reader structure"]
impl crate::Readable for SPI_WR_STATUS_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_wr_status::W](W) writer structure"]
impl crate::Writable for SPI_WR_STATUS_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_WR_STATUS to value 0"]
impl crate::Resettable for SPI_WR_STATUS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
